==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridColumnOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescriptionMetadata } from "./ApplyButtonClickEventArgsDescriptionMetadata";
import { CancelButtonClickEventArgsDescriptionMetadata } from "./CancelButtonClickEventArgsDescriptionMetadata";
import { GridColumnOptionsBaseDescriptionMetadata } from "./GridColumnOptionsBaseDescriptionMetadata";
import { GridColumnOptionsDescription } from "./GridColumnOptionsDescription";
/**
 * @hidden
 */
var GridColumnOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsDescriptionMetadata, _super);
    function GridColumnOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsDescriptionMetadata.a == null) {
            GridColumnOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsDescriptionMetadata.c(GridColumnOptionsDescriptionMetadata.a);
        }
        if (a.g(GridColumnOptionsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnOptionsDescriptionMetadata.a);
        ApplyButtonClickEventArgsDescriptionMetadata.d(a);
        CancelButtonClickEventArgsDescriptionMetadata.d(a);
    };
    GridColumnOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.c(a);
        a.item("ColumnNameFontFamily", "(w:ColumnNameFontFamily/FontFamilyTransform,xam:ColumnNameFontFamily,wf:ColumnNameFontFamily,web:columnNameTextStyle/FontFamilyTransform)String");
        a.item("ColumnNameFontSize", "(w:ColumnNameFontSize,xam:ColumnNameFontSize,wf:ColumnNameFontSize,web:columnNameTextStyle/FontSizeTransform)Number:double");
        a.item("ColumnNameFontStyle", "(w:ColumnNameFontStyle/FontStyleTransform,xam:ColumnNameFontFamily/FontStyleTransform,wf:ColumnNameFontFamily/FontStyleTransform,web:columnNameTextStyle/FontStyleTransform)String");
        a.item("ColumnNameFontWeight", "(w:ColumnNameFontWeight/FontWeightTransform,xam:ColumnNameFontFamily/FontWeightTransform,wf:ColumnNameFontFamily/FontWeightTransform,web:columnNameTextStyle/FontWeightTransform)String");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
        a.item("HeaderVisible", "Boolean");
        a.item("SortOptionsVisible", "Boolean");
        a.item("MoveOptionsVisible", "Boolean");
        a.item("PinOptionsVisible", "Boolean");
        a.item("HideOptionsVisible", "Boolean");
        a.item("GroupOptionsVisible", "Boolean");
        a.item("FilterOptionsVisible", "Boolean");
        a.item("SummaryOptionsVisible", "Boolean");
        a.item("SortHeaderCaption", "String");
        a.item("SortAscendingCaption", "String");
        a.item("SortDescendingCaption", "String");
        a.item("MoveHeaderCaption", "String");
        a.item("MoveLeftCaption", "String");
        a.item("MoveRightCaption", "String");
        a.item("PinHeaderCaption", "String");
        a.item("PinLeftCaption", "String");
        a.item("PinRightCaption", "String");
        a.item("ApplyFiltersButtonCaption", "String");
        a.item("CancelFiltersButtonCaption", "String");
        a.item("ClearColumnFiltersCaption", "String");
        a.item("SummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("SummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualSummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualSummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("FilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("FilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualFilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualFilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("FilterListPlaceholderText", "String");
        a.item("ApplyButtonClickRef", "EventRef::applyButtonClick");
        a.item("CancelButtonClickRef", "EventRef::cancelButtonClick");
    };
    GridColumnOptionsDescriptionMetadata.d = function (a) {
        GridColumnOptionsDescriptionMetadata.b(a);
        a.u("GridColumnOptions", function () { return new GridColumnOptionsDescription(); });
        a.t("GridColumnOptions", GridColumnOptionsDescriptionMetadata.a);
    };
    GridColumnOptionsDescriptionMetadata.$t = markType(GridColumnOptionsDescriptionMetadata, 'GridColumnOptionsDescriptionMetadata');
    GridColumnOptionsDescriptionMetadata.a = null;
    return GridColumnOptionsDescriptionMetadata;
}(Base));
export { GridColumnOptionsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridColumnOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescriptionMetadata } from "./ApplyButtonClickEventArgsDescriptionMetadata";
import { CancelButtonClickEventArgsDescriptionMetadata } from "./CancelButtonClickEventArgsDescriptionMetadata";
import { GridColumnOptionsBaseDescriptionMetadata } from "./GridColumnOptionsBaseDescriptionMetadata";
import { GridColumnOptionsDescription } from "./GridColumnOptionsDescription";
/**
 * @hidden
 */
var GridColumnOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsDescriptionMetadata, _super);
    function GridColumnOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsDescriptionMetadata.a == null) {
            GridColumnOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsDescriptionMetadata.c(GridColumnOptionsDescriptionMetadata.a);
        }
        if (a.j(GridColumnOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnOptionsDescriptionMetadata.a);
        ApplyButtonClickEventArgsDescriptionMetadata.d(a);
        CancelButtonClickEventArgsDescriptionMetadata.d(a);
    };
    GridColumnOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.c(a);
        a.item("ColumnNameFontFamily", "(w:ColumnNameFontFamily/FontFamilyTransform,xam:ColumnNameFontFamily,wf:ColumnNameFontFamily,web:columnNameTextStyle/FontFamilyTransform)String");
        a.item("ColumnNameFontSize", "(w:ColumnNameFontSize,xam:ColumnNameFontSize,wf:ColumnNameFontSize,web:columnNameTextStyle/FontSizeTransform)Number:double");
        a.item("ColumnNameFontStyle", "(w:ColumnNameFontStyle/FontStyleTransform,xam:ColumnNameFontFamily/FontStyleTransform,wf:ColumnNameFontFamily/FontStyleTransform,web:columnNameTextStyle/FontStyleTransform)String");
        a.item("ColumnNameFontWeight", "(w:ColumnNameFontWeight/FontWeightTransform,xam:ColumnNameFontFamily/FontWeightTransform,wf:ColumnNameFontFamily/FontWeightTransform,web:columnNameTextStyle/FontWeightTransform)String");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
        a.item("HeaderVisible", "Boolean");
        a.item("SortOptionsVisible", "Boolean");
        a.item("MoveOptionsVisible", "Boolean");
        a.item("PinOptionsVisible", "Boolean");
        a.item("HideOptionsVisible", "Boolean");
        a.item("GroupOptionsVisible", "Boolean");
        a.item("FilterOptionsVisible", "Boolean");
        a.item("SummaryOptionsVisible", "Boolean");
        a.item("SortHeaderCaption", "String");
        a.item("SortAscendingCaption", "String");
        a.item("SortDescendingCaption", "String");
        a.item("MoveHeaderCaption", "String");
        a.item("MoveLeftCaption", "String");
        a.item("MoveRightCaption", "String");
        a.item("PinHeaderCaption", "String");
        a.item("PinLeftCaption", "String");
        a.item("PinRightCaption", "String");
        a.item("ApplyFiltersButtonCaption", "String");
        a.item("CancelFiltersButtonCaption", "String");
        a.item("ClearColumnFiltersCaption", "String");
        a.item("SummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("SummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualSummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualSummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("FilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("FilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualFilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualFilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("FilterListPlaceholderText", "String");
        a.item("ApplyButtonClickRef", "EventRef::applyButtonClick");
        a.item("CancelButtonClickRef", "EventRef::cancelButtonClick");
    };
    GridColumnOptionsDescriptionMetadata.d = function (a) {
        GridColumnOptionsDescriptionMetadata.b(a);
        a.aa("GridColumnOptions", function () { return new GridColumnOptionsDescription(); });
        a.z("GridColumnOptions", GridColumnOptionsDescriptionMetadata.a);
    };
    GridColumnOptionsDescriptionMetadata.$t = markType(GridColumnOptionsDescriptionMetadata, 'GridColumnOptionsDescriptionMetadata');
    GridColumnOptionsDescriptionMetadata.a = null;
    return GridColumnOptionsDescriptionMetadata;
}(Base));
export { GridColumnOptionsDescriptionMetadata };
